@@ -1,5 +1,12 @@
 # from canalyst_candas.candas import FormulaTree, FuncMusic, Model, ModelMap, ModelSet
-from canalyst_candas.candas import FuncMusic, Model, ModelMap, ModelSet, Chart
+from canalyst_candas.candas import (
+    FuncMusic,
+    Model,
+    ModelMap,
+    ModelSet,
+    Chart,
+)
+from canalyst_candas.utils import get_chart_brand_config
 import canalyst_candas.version as version
 
 __version__ = version.__version__
