@@ -7,6 +7,7 @@ DEFAULT_DIR = tempfile.gettempdir()
 ROOT_DIR = Path().resolve()
 MDS_HOST = "https://mds.canalyst.com"
 WP_HOST = "https://app.canalyst.com"
+VERIFY_SSL = True
 
 
 def create_config():
@@ -28,6 +29,7 @@ def create_config():
             "default_dir": "",
             "mds_host": "",
             "wp_host": "",
+            "verify_ssl": True,
         }
         config_file.write_text(json.dumps(config_file_json))
         print(
